:orphan:

`plasmapy.plasma.sources.openpmd_hdf5`
======================================

.. currentmodule:: plasmapy.plasma.sources.openpmd_hdf5

.. automodapi::  plasmapy.plasma.sources.openpmd_hdf5
